<?php

namespace Drupal\ddate_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use EmperorNortonCommands\lib\Ddate;

/**
 * Defines a ddate block block type.
 *
 * @Block(
 *   id = "ddate_block",
 *   admin_label = @Translation("Ddate Block"),
 *   category = @Translation("Ddate"),
 * )
 */
class DdateBlock extends BlockBase implements BlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['ddate_block_format'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Format'),
      '#description' => $this->t('The format of the outputted date string, e.g. %{%A, %e of %B%}, %Y. %N%n&lt;br&gt;Celebrate %H'),
      '#default_value' => isset($config['ddate_block_format']) ? $config['ddate_block_format'] : '',
    );

    $form['ddate_block_date'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Date'),
      '#description' => $this->t('Enter a custom date (dmY, e.g. 29022012 for 29th of February 2012). If not set todays date is shown.'),
      '#default_value' => isset($config['ddate_block_date']) ? $config['ddate_block_date'] : '',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['ddate_block_format'] = $values['ddate_block_format'];
    $this->configuration['ddate_block_date'] = $values['ddate_block_date'];
  }

  /**
   * @inheritdoc
   */
  public function build() {
    $config = $this->getConfiguration();
    $ddate = new Ddate();

    if (!empty($config['ddate_block_format'])) {
      $format = $config['ddate_block_format'];
    }
    else {
      $format = '%{%A, %e of %B%}, %Y. %N%n<br>Celebrate %H';
    }

    if (!empty($config['ddate_block_date'])) {
      $date = $config['ddate_block_date'];
    }
    else {
      $date = date('dmY');
    }

    return [
      '#markup' => $ddate->ddate($format, $date),
    ];
  }

}
